@@ -5,7 +5,7 @@
 #  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 #
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-""""Modules to configure and estimate a local constant model."""
+"""Modules to configure and estimate a Local constant model."""
 
 from dataclasses import dataclass
 import numpy as np
@@ -59,7 +59,7 @@ class ModelLConstant:
     """Local constant model.
     
     This is the model class that prepares the data and estimates a local
-    constant model [1,2]_.
+    constant model [1,2].
     
     Parameters
     -----------
@@ -89,7 +89,6 @@ class ModelLConstant:
     the value of travel time." Transportation Research Part A: Policy and 
     Practice 41.9 (2007): 842-856.
     """
-
     def __init__(self, params: ConfigLConstant, arrays: ModelArrays):
         self.params = params
         self.arrays = arrays
@@ -119,12 +118,13 @@ class ModelLConstant:
         Returns
         -------
         p : numpy.ndarray
-            The estimated choice probability at each mid point of the VTT grid. 
-            The first point is always zero while the last point is always equal 
-            to the second last for compatibility with plots.
+            The estimates of the cumulative choice probability (CDF), evaluated 
+            at each mid point of the VTT grid. The first point is always zero 
+            while the last point is always equal to the second last for 
+            compatibility with plots.
         vtt : numpy.ndarray
             The estimated VTT per respondent, based in the estimated 
-            probabilities (`p`) and the sample.
+            CDF points (`p`) and the sample.
         """
         p = ModelLConstant.nadaraya_watson(self.vtt_mid[1:-1],~self.arrays.Choice.flatten(),self.arrays.BVTT.flatten(),self.params.kernelWidth)
 
