@@ -5,6 +5,7 @@
 #  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 #
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""Modules to configure and estimate a Local logit model."""
 from dataclasses import dataclass
 import numpy as np
 from scipy.optimize import minimize
@@ -50,7 +51,7 @@ class ModelLocLogit:
     """Local logit model.
     
     This is the model class that prepares the data and estimates a local 
-    logit model [1]_.
+    logit model [1].
     
     Parameters
     -----------
@@ -106,12 +107,13 @@ class ModelLocLogit:
         Returns
         -------
         p : numpy.ndarray
-            The choice probabilities at each interval of the VTT grid. 
-            The first point is always zero while the last point is always 
-            equal to the second last for compatibility with plots.
+            The estimates of the cumulative choice probability (CDF), evaluated 
+            at each interval of the VTT grid. The first point is always zero 
+            while the last point is always equal to the second last for 
+            compatibility with plots.
         vtt : numpy.ndarray
             The estimated VTT per respondent, based in the estimated 
-            probabilities (`p`) and the sample.
+            CDF points (`p`) and the sample.
         ll : float
             The log-likelihood function at the optimum of the estimation.
         """
