@@ -5,6 +5,7 @@
 #  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 #
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""Modules to configure and estimate a Logistic regression-based model."""
 from dataclasses import dataclass
 from typing import Optional, Tuple
 from scipy.optimize import minimize
@@ -62,23 +63,23 @@ class ConfigLogistic:
         return errorList
 
 class ModelLogistic:
+    """Logistic regression model.
+    
+    This is the model class that prepares the data and estimates 
+    the logistic regression.
+    
+    Parameters
+    -----------
+    params : ConfigLogistic
+        A configuration class of a logistic regression model.
+    arrays : ModelArrays
+        Model arrays created with `make_modelarrays`
+        
+    Attributes
+    ----------
+    None.
+    """
     def __init__(self, cfg: ConfigLogistic, arrays: ModelArrays):
-        """Logistic regression model.
-        
-        This is the model class that prepares the data and estimates 
-        the logistic regression.
-        
-        Parameters
-        -----------
-        params : ConfigLogistic
-            A configuration class of a logistic regression model.
-        arrays : ModelArrays
-            Model arrays created with `make_modelarrays`
-            
-        Attributes
-        ----------
-        None.
-        """
         self.cfg = cfg
         self.arrays = arrays
 
