@@ -5,6 +5,7 @@
 #  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 #
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""Modules to configure and estimate a Rouwendal model."""
 from dataclasses import dataclass
 from typing import Tuple
 from scipy.optimize import minimize
@@ -62,7 +63,7 @@ class ModelRouwendal:
     """Rouwendal model.
     
     This is the model class that prepares the data and estimates 
-    the Rouwendal model [1]_.
+    the Rouwendal model [1].
     
     Parameters
     -----------
@@ -118,23 +119,24 @@ class ModelRouwendal:
 
         Returns
         -------
-        q_prob : float
-            The estimated probability of consistent choice.
         q_est : float
             The estimated parameter that generates the probability of 
             consistent choice.
         q_se : float
             The standard error of the parameter of consistent choice.
+        q_prob : float
+            The estimated probability of consistent choice.
         x : numpy.ndarray
-            The estimated parameters at each point of the VTT grid.
+            The estimated density parameters at each point of the VTT grid.
         se : numpy.ndarray
-            The standard errors of x.
+            The standard errors of `x`.
         p : numpy.ndarray
-            The cumulative probability of the VTT at each support point. 
-            The first point is always zero for compatibility with plots.
+            The estimates of the cumulative probability function (CDF) of 
+            the VTT at each support point. The first point is always zero 
+            for compatibility with plots.
         vtt : numpy.ndarray
             The estimated VTT for each respondent, based in the estimated 
-            probabilities and the VTT grid.
+            CDF poonts (p) and the VTT grid.
         init_ll : float
             Value of log-likelihood function in the initial value of startQ. 
             Starting values of support point parameters are equal to zero.
