@@ -5,6 +5,7 @@
 #  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 #
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""Modules to configure and estimate a Random Valuation model."""
 from dataclasses import dataclass
 from typing import Optional, Tuple
 from scipy.optimize import minimize
@@ -50,31 +51,32 @@ class ConfigRV:
         return errorList
 
 class ModelRV:
+    """Random valuation model.
+    
+    This is the model class that prepares the data and estimates 
+    the random valuation model [1].
+    
+    Parameters
+    -----------
+    params : ConfigRV
+        A configuration class of a random valuation model.
+    arrays : ModelArrays
+        Model arrays created with `make_modelarrays`
+        
+    Attributes
+    ----------
+    None.
+
+    References
+    ----------
+    [1] Ojeda-Cabral, Manuel, Richard Batley, and Stephane Hess. "The 
+    value of travel time: random utility versus random valuation." 
+    Transportmetrica A: Transport Science 12.3 (2016): 230-248.
+    """
     def __init__(self, cfg: ConfigRV, arrays: ModelArrays):
         self.cfg = cfg
         self.arrays = arrays
-        """Random valuation model.
-        
-        This is the model class that prepares the data and estimates 
-        the random valuation model [1]_.
-        
-        Parameters
-        -----------
-        params : ConfigRV
-            A configuration class of a random valuation model.
-        arrays : ModelArrays
-            Model arrays created with `make_modelarrays`
-            
-        Attributes
-        ----------
-        None.
 
-        References
-        ----------
-        [1] Ojeda-Cabral, Manuel, Richard Batley, and Stephane Hess. "The 
-        value of travel time: random utility versus random valuation." 
-        Transportmetrica A: Transport Science 12.3 (2016): 230-248.
-        """
     def run(self):
         """Estimates the random valuation model.
         
